import { RequestType, IRequestHandler, NotificationType, INotificationHandler, ResponseError, ErrorCodes } from 'vscode-jsonrpc';
import { InitializeParams, InitializeResult, InitializeError, ShutdownParams, ExitParams, DidChangeConfigurationParams, DidOpenTextDocumentParams, DidChangeTextDocumentParams, DidCloseTextDocumentParams, DidChangeWatchedFilesParams, FileEvent, FileChangeType, PublishDiagnosticsParams, Diagnostic, Severity, Position, TextDocumentIdentifier, TextDocumentPosition, TextDocumentSyncKind, HoverResult, CompletionOptions, CompletionItemKind, CompletionItem, TextEdit, CompletionRequest } from './protocol';
import { Event } from './utils/events';
export { RequestType, IRequestHandler, NotificationType, INotificationHandler, ResponseError, ErrorCodes, InitializeParams, InitializeResult, InitializeError, ShutdownParams, ExitParams, DidChangeConfigurationParams, DidChangeWatchedFilesParams, FileEvent, FileChangeType, DidOpenTextDocumentParams, DidChangeTextDocumentParams, DidCloseTextDocumentParams, PublishDiagnosticsParams, Diagnostic, Severity, Position, TextDocumentIdentifier, TextDocumentPosition, TextDocumentSyncKind, HoverResult, CompletionOptions, CompletionItemKind, CompletionItem, TextEdit, CompletionRequest };
export { Event };
import * as fm from './files';
export declare namespace Files {
    let uriToFilePath: typeof fm.uriToFilePath;
    let resolveModule: typeof fm.resolveModule;
}
export interface ITextDocument {
    uri: string;
    getText(): string;
}
export declare class TextDocumentChangeEvent {
    document: ITextDocument;
}
export declare class TextDocuments {
    private _documents;
    private _onDidChangeContent;
    constructor();
    syncKind: TextDocumentSyncKind;
    onDidChangeContent: Event<TextDocumentChangeEvent>;
    get(uri: string): ITextDocument;
    all(): ITextDocument[];
    keys(): string[];
    listen(connection: IConnection): void;
}
export declare class ErrorMessageTracker {
    private messages;
    constructor();
    add(message: string): void;
    sendErrors(connection: {
        window: RemoteWindow;
    }): void;
}
export interface RemoteConsole {
    error(message: string): any;
    warn(message: string): any;
    info(message: string): any;
    log(message: string): any;
}
export interface RemoteWindow {
    showErrorMessage(message: string): any;
    showWarningMessage(message: string): any;
    showInformationMessage(message: string): any;
}
export interface IConnection {
    listen(): void;
    onRequest<P, R, E>(type: RequestType<P, R, E>, handler: IRequestHandler<P, R, E>): void;
    sendNotification<P>(type: NotificationType<P>, params?: P): void;
    onNotification<P>(type: NotificationType<P>, handler: INotificationHandler<P>): void;
    onInitialize(handler: IRequestHandler<InitializeParams, InitializeResult, InitializeError>): void;
    onShutdown(handler: IRequestHandler<ShutdownParams, void, void>): void;
    onExit(handler: INotificationHandler<ExitParams>): void;
    console: RemoteConsole;
    window: RemoteWindow;
    onDidChangeConfiguration(handler: INotificationHandler<DidChangeConfigurationParams>): void;
    onDidChangeWatchedFiles(handler: INotificationHandler<DidChangeWatchedFilesParams>): void;
    onDidOpenTextDocument(handler: INotificationHandler<DidOpenTextDocumentParams>): void;
    onDidChangeTextDocument(handler: INotificationHandler<DidChangeTextDocumentParams>): void;
    onDidCloseTextDocument(handler: INotificationHandler<DidCloseTextDocumentParams>): void;
    sendDiagnostics(args: PublishDiagnosticsParams): void;
    onHover(handler: IRequestHandler<TextDocumentPosition, HoverResult, void>): void;
    onCompletionRequest(handler: IRequestHandler<TextDocumentPosition, CompletionItem[], void>): void;
    onCompletionResolveRequest(handler: IRequestHandler<CompletionItem, CompletionItem, void>): void;
    dispose(): void;
}
export declare function createConnection(inputStream: NodeJS.ReadableStream, outputStream: NodeJS.WritableStream): IConnection;
