import { RequestType, NotificationType } from 'vscode-jsonrpc';
export interface HostCapabilities {
}
export declare enum TextDocumentSyncKind {
    None = 0,
    Full = 1,
    Incremental = 2,
}
export interface CompletionOptions {
    resolveProvider?: boolean;
    triggerCharacters?: string[];
}
export interface ServerCapabilities {
    textDocumentSync?: number;
    hoverProvider?: boolean;
    completionProvider?: CompletionOptions;
}
/**
 * The initialize command is send from the client to the worker.
 * It is send once as the first command after starting up the
 * worker.
 */
export declare namespace InitializeRequest {
    const type: RequestType<InitializeParams, InitializeResult, InitializeError>;
}
export interface InitializeParams {
    rootFolder: string;
    capabilities: HostCapabilities;
}
export interface InitializeResult {
    capabilities: ServerCapabilities;
}
export interface InitializeError {
    retry: boolean;
}
/**
 * The shutdown command is send from the client to the worker.
 * It is send once when the client descides to shutdown the
 * worker. The only event that is send after a shudown request
 * is the exit event.
 */
export declare namespace ShutdownRequest {
    const type: RequestType<ShutdownParams, void, void>;
}
export interface ShutdownParams {
}
/**
 * The exit event is send from the client to the worker to
 * ask the worker to exit its process.
 */
export declare namespace ExitNotification {
    const type: NotificationType<ExitParams>;
}
export interface ExitParams {
}
/**
 * The configuration change event is send from the client to the worker
 * when the client's configuration has changed. The event contains
 * the changed configuration as defined by the language worker statically
 * in it's extension manifest.
 */
export declare namespace DidChangeConfigurationNotification {
    const type: NotificationType<DidChangeConfigurationParams>;
}
export interface DidChangeConfigurationParams {
    settings: any;
}
export declare enum MessageType {
    Error = 1,
    Warning = 2,
    Info = 3,
    Log = 4,
}
/**
 * The show message event is send from a worker to a client to ask
 * the client to display a particular message in the user interface
 */
export declare namespace ShowMessageNotification {
    const type: NotificationType<ShowMessageParams>;
}
export interface ShowMessageParams {
    type: number;
    message: string;
}
export declare namespace LogMessageNotification {
    let type: NotificationType<LogMessageParams>;
}
export interface LogMessageParams {
    type: number;
    message: string;
}
/**
 * Position in a text document expressed as (zero-based) line and character offset.
 */
export interface Position {
    /**
     * Line Position in a document (zero-based)
     */
    line: number;
    /**
     * Character offset on a line in a document (zero-based)
     */
    character: number;
}
/**
 * A range in a text document.
 */
export interface Range {
    /**
     * The range's start position
     */
    start: Position;
    /**
     * The range's end position
     */
    end: Position;
}
export interface HTMLContentElement {
    formattedText?: string;
    text?: string;
    className?: string;
    style?: string;
    customStyle?: any;
    tagName?: string;
    children?: HTMLContentElement[];
    isText?: boolean;
}
export interface TextDocumentIdentifier {
    /**
     * A URI identifying the resource in the client.
     */
    uri: string;
}
export interface TextDocumentPosition extends TextDocumentIdentifier {
    /**
     * The position inside the text document.
     */
    position: Position;
}
/**
 * The document event is send from the client to the worker to signal
 * newly opened, changed and closed documents.
 */
export declare namespace DidOpenTextDocumentNotification {
    const type: NotificationType<DidOpenTextDocumentParams>;
}
export interface DidOpenTextDocumentParams extends TextDocumentIdentifier {
    /**
     * The content of the opened document.
     */
    text: string;
}
export declare namespace DidChangeTextDocumentNotification {
    const type: NotificationType<DidChangeTextDocumentParams>;
}
/**
 * The arguments describing a change to a text document. If range and rangeLength are omitted
 * the new text is considered to be the full content of the document.
 */
export interface DidChangeTextDocumentParams extends TextDocumentIdentifier {
    /**
     * The range of the document that changed.
     */
    range?: Range;
    /**
     * The length of the range that got replaced.
     */
    rangeLength?: number;
    /**
     * The new text of the document.
     */
    text: string;
}
export declare namespace DidCloseTextDocumentNotification {
    const type: NotificationType<DidCloseTextDocumentParams>;
}
export interface DidCloseTextDocumentParams extends TextDocumentIdentifier {
}
export declare namespace DidChangeWatchedFilesNotification {
    const type: NotificationType<DidChangeWatchedFilesParams>;
}
export interface DidChangeWatchedFilesParams {
    changes: FileEvent[];
}
export declare enum FileChangeType {
    Created = 1,
    Changed = 2,
    Deleted = 3,
}
export interface FileEvent {
    uri: string;
    type: number;
}
/**
 * Diagnostics notification are send from the worker to clients to signal
 * results of validation runs
 */
export declare namespace PublishDiagnosticsNotification {
    const type: NotificationType<PublishDiagnosticsParams>;
}
export interface PublishDiagnosticsParams {
    /**
     * The URI for which diagnostic information is reported.
     */
    uri: string;
    /**
     * An array of diagnostic information items.
     */
    diagnostics: Diagnostic[];
}
export declare enum Severity {
    Error = 0,
    Warning = 1,
    Information = 2,
    Hint = 3,
}
/**
 * Item of diagnostic information found in a DiagnosticEvent message.
 */
export interface Diagnostic {
    /**
     * Starting position at which text appies.
     */
    start: Position;
    /**
     * The last position at which the text applies. Can be omitted.
     */
    end?: Position;
    /**
     * The diagnostic's severity. Can be omitted. If omitted it is up to the
     * client to interpret diagnostics as error, warning or info.
     */
    severity?: number;
    /**
     * The diagnostic code. Can be omitted.
     */
    code?: string;
    /**
     * The diagnostic message.
     */
    message: string;
}
export declare enum CompletionItemKind {
    Text = 0,
    Method = 1,
    Function = 2,
    Constructor = 3,
    Field = 4,
    Variable = 5,
    Class = 6,
    Interface = 7,
    Module = 8,
    Property = 9,
    Unit = 10,
    Value = 11,
    Enum = 12,
    Keyword = 13,
    Snippet = 14,
    Color = 15,
    File = 16,
    Reference = 17,
}
export interface CompletionItem {
    label: string;
    kind?: number;
    detail?: string;
    documentation?: string;
    sortText?: string;
    filterText?: string;
    insertText?: string;
    textEdit?: TextEdit;
}
export declare namespace CompletionItem {
    function create(label: string): CompletionItem;
}
export interface TextEdit {
    range: Range;
    newText: string;
}
export declare namespace TextEdit {
    function replace(range: Range, newText: string): TextEdit;
    function insert(position: Position, newText: string): TextEdit;
    function del(range: Range): TextEdit;
}
export declare namespace CompletionRequest {
    const type: RequestType<TextDocumentPosition, CompletionItem[], void>;
}
export declare namespace CompletionResolveRequest {
    const type: RequestType<CompletionItem, CompletionItem, void>;
}
export declare namespace HoverRequest {
    const type: RequestType<TextDocumentPosition, HoverResult, void>;
}
/**
 * The result of a hove request.
 */
export interface HoverResult {
    /**
     * The hover's content
     */
    content: string | HTMLContentElement;
    /**
     * An optional range
     */
    range?: Range;
}
